=======
Credits
=======

This library is based on the following paper: [Paper link here]

Development Lead
----------------

* Akshay Sood <sood.iitd@gmail.com>

Acknowledgements
----------------

This package was refined using Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
